# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_element_states import SentienceElementStates

class TestSentienceElementStates(unittest.TestCase):
    """SentienceElementStates unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceElementStates:
        """Test SentienceElementStates
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceElementStates`
        """
        model = SentienceElementStates()
        if include_optional:
            return SentienceElementStates(
                is_disabled = True,
                is_checked = True,
                is_expanded = True
            )
        else:
            return SentienceElementStates(
        )
        """

    def testSentienceElementStates(self):
        """Test SentienceElementStates"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
