# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_interactable_element import SentienceInteractableElement

class TestSentienceInteractableElement(unittest.TestCase):
    """SentienceInteractableElement unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceInteractableElement:
        """Test SentienceInteractableElement
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceInteractableElement`
        """
        model = SentienceInteractableElement()
        if include_optional:
            return SentienceInteractableElement(
                id = 56,
                uid = '',
                tag = '',
                role = '',
                text = '',
                selector = '',
                bbox = sentience_sdk.models.bounding_box.BoundingBox(
                    x = 56, 
                    y = 56, 
                    w = 56, 
                    h = 56, ),
                is_visible = True,
                z_index = 56,
                attributes = {
                    'key' : ''
                    },
                states = sentience_sdk.models.element_states.ElementStates(
                    is_disabled = True, 
                    is_checked = True, 
                    is_expanded = True, )
            )
        else:
            return SentienceInteractableElement(
                id = 56,
                tag = '',
                role = '',
                bbox = sentience_sdk.models.bounding_box.BoundingBox(
                    x = 56, 
                    y = 56, 
                    w = 56, 
                    h = 56, ),
                is_visible = True,
        )
        """

    def testSentienceInteractableElement(self):
        """Test SentienceInteractableElement"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
