# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sentience_sdk.models.sentience_output_format import SentienceOutputFormat
from sentience_sdk.models.sentience_reader_mode_response_data import SentienceReaderModeResponseData
from typing import Optional, Set
from typing_extensions import Self

class SentienceReaderModeResponse(BaseModel):
    """
    Response for 'read' mode
    """ # noqa: E501
    mode: StrictStr
    status: StrictStr
    url: StrictStr
    content: StrictStr
    title: Optional[StrictStr] = None
    format: Optional[SentienceOutputFormat] = SentienceOutputFormat.MARKDOWN
    author: Optional[StrictStr] = None
    published_date: Optional[datetime] = None
    word_count: Optional[StrictInt] = None
    reading_time_minutes: Optional[StrictInt] = None
    timestamp: Optional[datetime] = None
    data: Optional[SentienceReaderModeResponseData] = None
    __properties: ClassVar[List[str]] = ["mode", "status", "url", "content", "title", "format", "author", "published_date", "word_count", "reading_time_minutes", "timestamp", "data"]

    @field_validator('mode')
    def mode_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['read']):
            raise ValueError("must be one of enum values ('read')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['success', 'error']):
            raise ValueError("must be one of enum values ('success', 'error')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SentienceReaderModeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if author (nullable) is None
        # and model_fields_set contains the field
        if self.author is None and "author" in self.model_fields_set:
            _dict['author'] = None

        # set to None if published_date (nullable) is None
        # and model_fields_set contains the field
        if self.published_date is None and "published_date" in self.model_fields_set:
            _dict['published_date'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SentienceReaderModeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "mode": obj.get("mode") if obj.get("mode") is not None else 'read',
            "status": obj.get("status"),
            "url": obj.get("url"),
            "content": obj.get("content"),
            "title": obj.get("title"),
            "format": obj.get("format") if obj.get("format") is not None else SentienceOutputFormat.MARKDOWN,
            "author": obj.get("author"),
            "published_date": obj.get("published_date"),
            "word_count": obj.get("word_count"),
            "reading_time_minutes": obj.get("reading_time_minutes"),
            "timestamp": obj.get("timestamp"),
            "data": SentienceReaderModeResponseData.from_dict(obj["data"]) if obj.get("data") is not None else None
        })
        return _obj


