# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_map_mode_response import SentienceMapModeResponse

class TestSentienceMapModeResponse(unittest.TestCase):
    """SentienceMapModeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceMapModeResponse:
        """Test SentienceMapModeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceMapModeResponse`
        """
        model = SentienceMapModeResponse()
        if include_optional:
            return SentienceMapModeResponse(
                mode = 'map',
                status = 'success',
                engine = 'performance',
                url = '',
                layout_viewport = sentience_sdk.models.layout_viewport.LayoutViewport(
                    width = 56, 
                    height = 56, 
                    device_pixel_ratio = 1.337, ),
                interactable_elements = [
                    sentience_sdk.models.interactable_element.InteractableElement(
                        id = 56, 
                        uid = '', 
                        tag = '', 
                        role = '', 
                        text = '', 
                        selector = '', 
                        bbox = sentience_sdk.models.bounding_box.BoundingBox(
                            x = 56, 
                            y = 56, 
                            w = 56, 
                            h = 56, ), 
                        is_visible = True, 
                        z_index = 56, 
                        attributes = {
                            'key' : ''
                            }, 
                        states = sentience_sdk.models.element_states.ElementStates(
                            is_disabled = True, 
                            is_checked = True, 
                            is_expanded = True, ), )
                    ],
                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                total_elements_extracted = 56,
                filters_applied = sentience_sdk.models.applied_filters.AppliedFilters(
                    limit = 56, 
                    filter = sentience_sdk.models.element_filter.ElementFilter(
                        min_area = 56, 
                        min_z_index = 56, 
                        allowed_roles = [
                            ''
                            ], 
                        allowed_tags = [
                            ''
                            ], ), ),
                proxy_failure = sentience_sdk.models.proxy_failure.ProxyFailure(
                    failure_reason = '', 
                    domain = '', 
                    fallback_successful = True, )
            )
        else:
            return SentienceMapModeResponse(
                mode = 'map',
                status = 'success',
                url = '',
                interactable_elements = [
                    sentience_sdk.models.interactable_element.InteractableElement(
                        id = 56, 
                        uid = '', 
                        tag = '', 
                        role = '', 
                        text = '', 
                        selector = '', 
                        bbox = sentience_sdk.models.bounding_box.BoundingBox(
                            x = 56, 
                            y = 56, 
                            w = 56, 
                            h = 56, ), 
                        is_visible = True, 
                        z_index = 56, 
                        attributes = {
                            'key' : ''
                            }, 
                        states = sentience_sdk.models.element_states.ElementStates(
                            is_disabled = True, 
                            is_checked = True, 
                            is_expanded = True, ), )
                    ],
        )
        """

    def testSentienceMapModeResponse(self):
        """Test SentienceMapModeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
