# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.api.sentience_observation_api import SentienceObservationApi


class TestSentienceObservationApi(unittest.TestCase):
    """SentienceObservationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SentienceObservationApi()

    def tearDown(self) -> None:
        pass

    def test_observe(self) -> None:
        """Test case for observe

        Observe and extract web content or element coordinates
        """
        pass


if __name__ == '__main__':
    unittest.main()
