# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SentienceRenderQuality(str, Enum):
    """
    Rendering engine selection.
    """

    """
    allowed enum values
    """
    PERFORMANCE = 'performance'
    PRECISION = 'precision'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SentienceRenderQuality from a JSON string"""
        return cls(json.loads(json_str))


