# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_processing_mode import SentienceProcessingMode

class TestSentienceProcessingMode(unittest.TestCase):
    """SentienceProcessingMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSentienceProcessingMode(self):
        """Test SentienceProcessingMode"""
        # inst = SentienceProcessingMode()

if __name__ == '__main__':
    unittest.main()
