# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_observe_request import SentienceObserveRequest

class TestSentienceObserveRequest(unittest.TestCase):
    """SentienceObserveRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceObserveRequest:
        """Test SentienceObserveRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceObserveRequest`
        """
        model = SentienceObserveRequest()
        if include_optional:
            return SentienceObserveRequest(
                url = 'https://news.ycombinator.com',
                mode = 'read',
                format = 'markdown',
                content_limit = 1000,
                options = sentience_sdk.models.observe_options.ObserveOptions(
                    render_quality = 'performance', 
                    limit = 10, 
                    filter = sentience_sdk.models.element_filter.ElementFilter(
                        min_area = 56, 
                        min_z_index = 56, 
                        allowed_roles = [
                            ''
                            ], 
                        allowed_tags = [
                            ''
                            ], ), 
                    viewport = sentience_sdk.models.viewport.Viewport(
                        width = 56, 
                        height = 56, ), ),
                proxy = 'http://user:pass@proxy.example.com:8080'
            )
        else:
            return SentienceObserveRequest(
                url = 'https://news.ycombinator.com',
        )
        """

    def testSentienceObserveRequest(self):
        """Test SentienceObserveRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
