# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_bounding_box import SentienceBoundingBox

class TestSentienceBoundingBox(unittest.TestCase):
    """SentienceBoundingBox unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceBoundingBox:
        """Test SentienceBoundingBox
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceBoundingBox`
        """
        model = SentienceBoundingBox()
        if include_optional:
            return SentienceBoundingBox(
                x = 56,
                y = 56,
                w = 56,
                h = 56
            )
        else:
            return SentienceBoundingBox(
                x = 56,
                y = 56,
                w = 56,
                h = 56,
        )
        """

    def testSentienceBoundingBox(self):
        """Test SentienceBoundingBox"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
