# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_reader_mode_response import SentienceReaderModeResponse

class TestSentienceReaderModeResponse(unittest.TestCase):
    """SentienceReaderModeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceReaderModeResponse:
        """Test SentienceReaderModeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceReaderModeResponse`
        """
        model = SentienceReaderModeResponse()
        if include_optional:
            return SentienceReaderModeResponse(
                mode = 'read',
                status = 'success',
                url = '',
                content = '',
                title = '',
                format = 'markdown',
                author = '',
                published_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                word_count = 56,
                reading_time_minutes = 56,
                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                data = sentience_sdk.models.reader_mode_response_data.ReaderModeResponse_data(
                    metadata = sentience_sdk.models.response_metadata.ResponseMetadata(
                        engine = 'performance', 
                        used_proxy = True, 
                        proxy_failure = sentience_sdk.models.proxy_failure.ProxyFailure(
                            failure_reason = '', 
                            domain = '', 
                            fallback_successful = True, ), ), )
            )
        else:
            return SentienceReaderModeResponse(
                mode = 'read',
                status = 'success',
                url = '',
                content = '',
        )
        """

    def testSentienceReaderModeResponse(self):
        """Test SentienceReaderModeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
